from django.apps import AppConfig

class DjangoTailwind4Config(AppConfig):
    """
    AppConfig for the django-tailwind4 app.
    This is what you'll add to INSTALLED_APPS in your settings.
    """
    default_auto_field = 'django.db.models.BigAutoField'
    name = 'django_tailwind_v4'